@@ -68,7 +68,7 @@ class TestMPRester:
     def test_get_materials_ids_doc(self, mpr):
         mpids = mpr.get_materials_ids("Al2O3")
         random.shuffle(mpids)
-        doc = mpr.materials.get_document_by_id(mpids.pop(0))
+        doc = mpr.materials.get_data_by_id(mpids.pop(0))
         assert doc.formula_pretty == "Al2O3"
 
     def test_get_structures(self, mpr):
@@ -138,7 +138,6 @@ class TestMPRester:
         dos = mpr.get_phonon_dos_by_material_id("mp-11659")
         assert isinstance(dos, PhononDos)
 
-    @pytest.mark.xfail  # temporary until api deploy
     def test_get_charge_density_data(self, mpr):
         chgcar = mpr.get_charge_density_from_material_id("mp-149")
         assert isinstance(chgcar, Chgcar)
